MethodChannelCustomPdfEditor class
An implementation of CustomPdfEditorPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- CustomPdfEditorPlatform
- MethodChannelCustomPdfEditor
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBytes(
) → Future< Uint8List?> -
Get PDF bytes
override
-
getPlatformVersion(
) → Future< String?> -
Get platform version
override
-
loadFromBytes(
Uint8List bytes, {String? password, Map< String, dynamic> ? config}) → Future<Map< String, dynamic> ?> -
Load PDF from bytes
override
-
loadFromPath(
String filePath, {String? password, Map< String, dynamic> ? config}) → Future<Map< String, dynamic> ?> -
Load PDF from file path
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
{String? outputPath}) → Future< bool> -
Save PDF
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited